summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorPhilip Withnall <philip@tecnocode.co.uk>2022-05-17 12:59:45 +0000
committerPhilip Withnall <philip@tecnocode.co.uk>2022-05-17 12:59:45 +0000
commit848d7718b60ab8bcb4a7ce52b953d85e9d337274 (patch)
tree821502951af8ea0926b619fe8f003916f2567b5d
parent5efbd51ea8b19e69b4f65ae1cacaffe40ae58b36 (diff)
parentddb0585e65dc31c5d352990f90307c4fd0d754d0 (diff)
downloadglib-848d7718b60ab8bcb4a7ce52b953d85e9d337274.tar.gz
Merge branch 'test-slice-threadinit' into 'main'
Moving slice-threadinit.c test to glib/tests/ See merge request GNOME/glib!2580
-rw-r--r--glib/tests/meson.build1
-rw-r--r--glib/tests/slice-known-pages.c (renamed from tests/slice-threadinit.c)55
-rw-r--r--tests/meson.build3
3 files changed, 32 insertions, 27 deletions
diff --git a/glib/tests/meson.build b/glib/tests/meson.build
index add0ce4f5..e562e63b5 100644
--- a/glib/tests/meson.build
+++ b/glib/tests/meson.build
@@ -105,6 +105,7 @@ glib_tests = {
'extra_sources' : ['memchunks.c'],
},
'slice-concurrent' : {},
+ 'slice-known-pages' : {},
'slist' : {},
'sort' : {},
'spawn-multithreaded' : {},
diff --git a/tests/meson.build b/tests/meson.build
index acf43ea13..777ba428c 100644
--- a/tests/meson.build
+++ b/tests/meson.build
@@ -16,9 +16,6 @@ subdir('gobject')
subdir('refcount')
tests = {
- 'slice-threadinit' : {
- 'dependencies' : [libgthread_dep],
- },
'module-test-library' : {
'dependencies' : [libgmodule_dep],
'export_dynamic' : true,
diff --git a/tests/slice-threadinit.c b/glib/tests/slice-known-pages.c
index e303aa0b2..ee856068b 100644
--- a/tests/slice-threadinit.c
+++ b/glib/tests/slice-known-pages.c
@@ -1,4 +1,4 @@
/* slice-threadinit.c - test GSlice across g_thread_init
* Copyright (C) 2007 Tim Janik
*
* This work is provided "as is"; redistribution and modification
@@ -18,15 +18,20 @@
* otherwise) arising in any way out of the use of this software, even
* if advised of the possibility of such damage.
*/
+
#include <glib.h>
-#define N_PAGES (101) /* number of pages to sample */
-#define SAMPLE_SIZE (7)
-#define PAGE_SIZE (128) /* must be <= minimum GSlice alignment block */
-#define MAGAZINE_PROBES { 97, 265, 347 } /* block sizes hopefully unused by g_thread_init */
-#define MAX_PROBE_TRIALS (1031) /* must be >= maximum magazine size */
+#define N_PAGES (101) /* number of pages to sample */
+#define SAMPLE_SIZE (7)
+#define PAGE_SIZE (128) /* must be <= minimum GSlice alignment block */
+#define MAGAZINE_PROBES \
+ { \
+ 97, 265, 347 \
+ } /* block sizes hopefully unused */
+#define MAX_PROBE_TRIALS (1031) /* must be >= maximum magazine size */
-#define ALIGN(size, base) ((base) * (gsize) (((size) + (base) - 1) / (base)))
+#define ALIGN(size, base) \
+ ((base) * (gsize) (((size) + (base) - 1) / (base)))
static struct {
void *page;
@@ -34,6 +39,7 @@ static struct {
} pages[N_PAGES] = { { NULL, NULL }, };
static const guint magazine_probes[] = MAGAZINE_PROBES;
+
#define N_MAGAZINE_PROBES G_N_ELEMENTS (magazine_probes)
static void
@@ -66,9 +72,8 @@ allocate_from_known_page (void)
return FALSE;
}
-int
-main (int argc,
- char *argv[])
+static void
+test_slice_known_pages (void)
{
gsize j, n_pages = 0;
void *mps[N_MAGAZINE_PROBES];
@@ -99,15 +104,15 @@ main (int argc,
release_trash_list (&free_list, SAMPLE_SIZE);
/* ensure that we can allocate from known pages */
- if (!allocate_from_known_page())
- g_error ("failed to allocate from magazine/page cache (before g_thread_init)");
+ g_assert_true (allocate_from_known_page());
+
/* release intermediate allocations */
release_trash_list (&free_list, SAMPLE_SIZE);
/* release magazine probes to be retained */
for (j = 0; j < N_MAGAZINE_PROBES; j++)
g_slice_free1 (magazine_probes[j], mps[j]);
- /* mps[*] now contains pointers to releaed slices */
+ /* mps[*] now contains pointers to released slices */
/* ensure probes were retained */
for (j = 0; j < N_MAGAZINE_PROBES; j++)
@@ -122,19 +127,15 @@ main (int argc,
trash = g_slist_prepend (trash, mem);
}
release_trash_list (&trash, magazine_probes[j]);
- if (k >= MAX_PROBE_TRIALS) /* failed to reallocate slice */
- g_error ("failed to reallocate slice from magazine (before g_thread_init): size=%d", magazine_probes[j]);
+ g_assert_cmpint (k, <, MAX_PROBE_TRIALS); /* failed to reallocate slice */
}
/* mps[*] now contains pointers to reallocated slices */
/* release magazine probes to be retained across g_thread_init */
for (j = 0; j < N_MAGAZINE_PROBES; j++)
g_slice_free1 (magazine_probes[j], mps[j]);
/* mps[*] now contains pointers to released slices */
- /* initialize threading (should retain allocator state) */
- g_thread_init (NULL);
-
/* ensure probes were retained */
for (j = 0; j < N_MAGAZINE_PROBES; j++)
{
@@ -148,19 +149,25 @@ main (int argc,
trash = g_slist_prepend (trash, mem);
}
release_trash_list (&trash, magazine_probes[j]);
- if (k >= MAX_PROBE_TRIALS) /* failed to reallocate slice */
- g_error ("failed to reallocate slice from magazine (after g_thread_init): size=%d", magazine_probes[j]);
+ g_assert_cmpint (k, <, MAX_PROBE_TRIALS); /* failed to reallocate slice */
}
/* mps[*] now contains pointers to reallocated slices */
/* ensure that we can allocate from known pages */
- if (!allocate_from_known_page())
- g_error ("failed to allocate from magazine/page cache (after g_thread_init)");
+ g_assert_true (allocate_from_known_page());
/* some cleanups */
for (j = 0; j < N_MAGAZINE_PROBES; j++)
g_slice_free1 (magazine_probes[j], mps[j]);
release_trash_list (&free_list, SAMPLE_SIZE);
+}
+
+int
+main (int argc, char *argv[])
+{
+ g_test_init (&argc, &argv, NULL);
+
+ g_test_add_func ("/slice/known_pages", test_slice_known_pages);
- return 0;
+ return g_test_run ();
}
@@ -1,4 +1,4 @@
-/* slice-threadinit.c - test GSlice across g_thread_init
+/* slice-known-pages.c - test GSlice across known pages
* Copyright (C) 2007 Tim Janik
*
@@ -122,19 +127,15 @@ main (int argc,
}
/* mps[*] now contains pointers to reallocated slices */
- /* release magazine probes to be retained across g_thread_init */
+ /* release magazine probes to be retained across known pages */
for (j = 0; j < N_MAGAZINE_PROBES; j++)
g_slice_free1 (magazine_probes[j], mps[j]);